@@ -15,7 +15,7 @@
 #' @export
 #' @family Scalable Dictionaries
 #' @references * Yeh C-CM, Kavantzas N, Keogh E. Matrix profile IV: Using Weakly Labeled Time Series
-#'   to Predict Outcomes. Proc VLDB Endow. 2017 Aug 1;10(12):1802–12.
+#'   to Predict Outcomes. Proc VLDB Endow. 2017 Aug 1;10(12):1802-12.
 #' @references Website: <https://sites.google.com/view/weaklylabeled>
 #' @examples
 #' # This is a fast toy example and results are useless. For a complete result, run the code inside
@@ -43,7 +43,7 @@ sdts_predict <- function(model, data, window_size) {
 
   for (i in 1:n_pat) {
     nn <- dist_profile(data, model$pattern[[i]])
-    dist_pro <- Re(sqrt(nn$distance_profile))
+    dist_pro <- sqrt(nn$distance_profile)
     anno <- dist_pro - model$thold[i]
     anno[anno >= 0] <- 0
     anno[anno < 0] <- -1
@@ -100,7 +100,7 @@ sdts_predict <- function(model, data, window_size) {
 #'
 #' @family Scalable Dictionaries
 #' @references * Yeh C-CM, Kavantzas N, Keogh E. Matrix profile IV: Using Weakly Labeled Time Series
-#'   to Predict Outcomes. Proc VLDB Endow. 2017 Aug 1;10(12):1802–12.
+#'   to Predict Outcomes. Proc VLDB Endow. 2017 Aug 1;10(12):1802-12.
 #' @references Website: <https://sites.google.com/view/weaklylabeled>
 #' @examples
 #' # This is a fast toy example and results are useless. For a complete result, run the code inside
@@ -183,5 +183,5 @@ sdts_score <- function(pred, gtruth, beta = 1) {
 
   f_score <- (1 + beta^2) * (pre * rec) / ((beta^2) * pre + rec)
 
-  return(list(f_score = f_score, precision = pre, recall = rec))
+  return(invisible(list(f_score = f_score, precision = pre, recall = rec)))
 }
