@@ -11,7 +11,7 @@
 #' adds the progress bar, `3` adds the finish sound. `exclusion_zone` is used to avoid  trivial
 #' matches; if a query data is provided (join similarity), this parameter is ignored.
 #'
-#' @param ... a `matrix` or a `vector`. If a second time series is supplied it will be a join matrix
+#' @param \dots a `matrix` or a `vector`. If a second time series is supplied it will be a join matrix
 #'   profile.
 #' @param window_size an `int`. Size of the sliding window.
 #' @param exclusion_zone a `numeric`. Size of the exclusion zone, based on window size (default is
@@ -30,15 +30,15 @@
 #'
 #' @references * Zhu Y, Zimmerman Z, Senobari NS, Yeh CM, Funning G. Matrix Profile II : Exploiting
 #'   a Novel Algorithm and GPUs to Break the One Hundred Million Barrier for Time Series Motifs and
-#'   Joins. Icdm. 2016 Jan 22;54(1):739–48.
+#'   Joins. Icdm. 2016 Jan 22;54(1):739-48.
 #' @references Website: <http://www.cs.ucr.edu/~eamonn/MatrixProfile.html>
 #'
 #' @examples
 #' mp <- stomp(mp_toy_data$data[1:200, 1], window_size = 30, verbose = 0)
-#'
-#' # using threads
-#' mp <- stomp_par(mp_toy_data$data[1:400, 1], window_size = 30, verbose = 0)
 #' \dontrun{
+#' #' # using threads
+#' mp <- stomp_par(mp_toy_data$data[1:400, 1], window_size = 30, verbose = 0)
+#'
 #' ref_data <- mp_toy_data$data[, 1]
 #' query_data <- mp_toy_data$data[, 2]
 #' # self similarity
@@ -46,7 +46,8 @@
 #' # join similarity
 #' mp2 <- stomp(ref_data, query_data, window_size = 30)
 #' }
-stomp <- function(..., window_size, exclusion_zone = 1 / 2, verbose = 2) {
+stomp <- function(..., window_size, exclusion_zone = getOption("tsmp.exclusion_zone", 1 / 2),
+                  verbose = getOption("tsmp.verbose", 2)) {
   argv <- list(...)
   argc <- length(argv)
   data <- argv[[1]]
@@ -88,7 +89,10 @@ stomp <- function(..., window_size, exclusion_zone = 1 / 2, verbose = 2) {
   matrix_profile_size <- data_size - window_size + 1
   num_queries <- query_size - window_size + 1
 
-  if (window_size > query_size / 2) {
+  if (query_size > data_size) {
+    stop("Query must be smaller or the same size as reference data.")
+  }
+  if (window_size > ceiling(query_size / 2)) {
     stop("Time series is too short relative to desired window size.", call. = FALSE)
   }
   if (window_size < 4) {
@@ -164,7 +168,8 @@ stomp <- function(..., window_size, exclusion_zone = 1 / 2, verbose = 2) {
         (nn$par$data_sd * nn$par$query_sd[i]))
     }
 
-    distance_profile <- Re(sqrt(distance_profile))
+    distance_profile[distance_profile < 0] <- 0
+    distance_profile <- sqrt(distance_profile)
     drop_value <- query_window[1, 1]
 
     # apply exclusion zone
